Implement OCC status interface

Change-Id: I43822cb28bc2d23398fb09352c9876e169c666f7
Signed-off-by: Vishwanatha Subbanna <vishwa@linux.vnet.ibm.com>
diff --git a/occ_manager.hpp b/occ_manager.hpp
index 067a6d2..a1b5234 100644
--- a/occ_manager.hpp
+++ b/occ_manager.hpp
@@ -6,6 +6,7 @@
 #include <functional>
 #include <sdbusplus/bus.hpp>
 #include "occ_pass_through.hpp"
+#include "occ_status.hpp"
 #include "config.h"
 
 namespace sdbusRule = sdbusplus::bus::match::rules;
@@ -28,8 +29,8 @@
         Manager& operator=(Manager&&) = default;
         ~Manager() = default;
 
         /** @brief Ctor - Add OCC pass-through objects on the bus. Create
          *         OCC objects when corresponding CPU inventory is created.
          *  @param[in] bus - handle to the bus
          */
         Manager(sdbusplus::bus::bus& bus):
@@ -68,11 +69,15 @@
             name.replace(index, std::strlen(CPU_NAME), OCC_NAME);
 
             auto path = fs::path(OCC_CONTROL_ROOT) / name;
-            objects.emplace_back(
+            passThroughObjects.emplace_back(
                 std::make_unique<PassThrough>(
                     bus,
                     path.c_str()));
 
+            statusObjects.emplace_back(
+                std::make_unique<Status>(
+                    bus,
+                    path.c_str()));
             return 0;
         }
 
@@ -81,7 +86,10 @@
         sdbusplus::bus::bus& bus;
 
         /** @brief OCC pass-through objects */
-        std::vector<std::unique_ptr<PassThrough>> objects;
+        std::vector<std::unique_ptr<PassThrough>> passThroughObjects;
+
+        /** @brief OCC Status objects */
+        std::vector<std::unique_ptr<Status>> statusObjects;
 
         /** @brief sbdbusplus match objects */
         std::vector<sdbusplus::bus::match_t> cpuMatches;
@@ -28,8 +29,8 @@
         ~Manager() = default;
 
-        /** @brief Ctor - Add OCC pass-through objects on the bus. Create
-         *         OCC objects when corresponding CPU inventory is created.
+        /** @brief Adds OCC pass-through and status objects on the bus
+         *         when corresponding CPU inventory is created.
          *  @param[in] bus - handle to the bus
          */